
/**
 * This script is based on the echobot.js example that comes with Strophe.
 * You can use it for any purposes.
 * All communication with ejabberd proceeds from here.
 */


/**
 * HTTP endpoint for ejabberd.
 */
var BOSH_SERVICE = '/http-bind';

/**
 * ID of multiuser chatroom.
 */
var mucRoomJID = 'test-room@conference.remoteguru.info';

/**
 * Global variables.
 */
var connection = null;
var paintObj;
var connectedp = false;



/**
 * The game begins here.
 */
$(document).ready(function () {
    connection = new Strophe.Connection(BOSH_SERVICE);
    paintObj = new paint;

    connection.connect('painter@remoteguru.info', 'secretPainter', onConnect);
    $(window).bind('unload', function() { connection.disconnect(); });
});


/**
 * This function is triggered as soon we are connected to the XMPP server.
 * This function prints log messages when we get connected/disconnected to/from
 * the XMPP server.  It then joins a chatroom.
 */
function onConnect(status)
{
    if (status == Strophe.Status.CONNECTING) {
	log('Strophe is connecting.');
    } else if (status == Strophe.Status.CONNFAIL) {
	log('Strophe failed to connect.');
    } else if (status == Strophe.Status.DISCONNECTING) {
	log('Strophe is disconnecting.');
    } else if (status == Strophe.Status.DISCONNECTED) {
        connectedp = false;

	log('Strophe is disconnected.');
    } else if (status == Strophe.Status.CONNECTED) {
        connectedp = true;

        // Now connect to MUC room.
        var joinMsg = $pres({to : mucRoomJID + '/' + connection.jid});
        connection.send(joinMsg.tree());

	log('Strophe is connected.');

	connection.addHandler(onMessage, null, 'message', null, null,  null); 
	connection.send($pres().tree());
    }
}


/**
 * This function is triggered everytime a message is received from the chatroom.
 * This message is then converted to an object and passed to img2_update() which
 * then draws it on the canvas.
 */
function onMessage(msg) {
    var to = msg.getAttribute('to');
    var from = msg.getAttribute('from');
    var type = msg.getAttribute('type');
    var bodyList = msg.getElementsByTagName('body');

    // We are only interested about messages coming from OTHER people in the room.
    if (type == "groupchat" && from !== (mucRoomJID + '/' + connection.jid) && bodyList.length > 0) {
	var body = bodyList[0];
        var drawList = body.getElementsByTagName('draw');

        // Lots of messages will have no 'draw' element.
        if (0 == drawList.length) return true;

        var drawElem = drawList[0];
        var drawData = { type : drawElem.getAttribute('type') };

        var start_x, start_y, end_x, end_y, x_list, y_list;
        if (start_x = drawElem.getAttribute('start_x')) drawData.start_x = start_x;
        if (start_y = drawElem.getAttribute('start_y')) drawData.start_y = start_y;
        if (end_x = drawElem.getAttribute('end_x')) drawData.end_x = end_x;
        if (end_y = drawElem.getAttribute('end_y')) drawData.end_y = end_y;
        if (x_list = drawElem.getAttribute('x_list')) drawData.x_list = x_list;
        if (y_list = drawElem.getAttribute('y_list')) drawData.y_list = y_list;

        paintObj.img2_update(drawData);
    }

    // we must return true to keep the handler alive.  
    // returning false would remove it after it finishes.
    return true;
}


/**
 * This function transfers drawing data to the chatroom.
 */
function wireTransfer(drawData) {
    if ( ! connectedp) return;

    var reply = $msg({to: mucRoomJID, type: 'groupchat'}).c('body').c('draw', drawData);

    connection.send(reply.tree());
}


/**
 * Log functions.  log messages are printed just below the drawing canvas.
 */
function log(msg) 
{
    $('#log').append('<div></div>').append(document.createTextNode(msg));
}


